# PyCout
> C++'s `cout << "Hello" << " World!" << endl;` in Python

[![Actions Status](https://github.com/ebonnal/pycout/workflows/unittest/badge.svg)](https://github.com/ebonnal/pycout/actions)
[![Actions Status](https://github.com/ebonnal/pycout/workflows/PyPI/badge.svg)](https://github.com/ebonnal/pycout/actions)

`pip install pycout`

```python
from pycout import *

cout << "Sending a " << 1000 << " hellos world!" << endl;
```
